==> macdaily-2018.11.6.dev17.tar.gz: macdaily-2018.11.6.dev17/macdaily/cmd/launch.py <==
# -*- coding: utf-8 -*-

import collections
import os
import plistlib

from macdaily.util.const import ROOT, bold, red, reset
from macdaily.util.misc import print_info, print_misc, print_scpt, print_term

try:
    import subprocess32 as subprocess
except ImportError:
    import subprocess


def run_script(argv, quiet, verbose):
    args = ' '.join(argv)
    print_scpt(args, os.devnull, verbose)
    stderr = subprocess.DEVNULL if quiet else None
    try:
        subprocess.check_call(argv, stdout=subprocess.DEVNULL, stderr=stderr)
    except subprocess.CalledProcessError:
        text = "macdaily: {}config{}: command `{}{!r}{} failed".format(red, reset, bold, args, reset)
        print_term(text, os.devnull, quiet)
        raise


def launch_askpass(quiet=False, verbose=False):
    text = 'Launching MacDaily SSH-AskPass program'
    print_info(text, os.devnull, quiet)

    path = 'Macintosh HD{}:img:askpass.icns'.format(ROOT.replace(os.path.sep, ":"))
    ASKPASS = ['#!/usr/bin/env osascript',
               '',
               '-- script based on https://github.com/theseal/ssh-askpass',
               '',
               'on run argv',
               '    set args to argv as text',
               '    if args starts with "--help" or args starts with "-h" then',
               '        return "macdaily-askpass [-h|--help] [prompt]"',
               '    end if',
               '    display dialog args with icon file ("{}") default button "OK" default answer "" with hidden answer'.format(path),
               "    return result's text returned",
               'end run',
               '']
    askpass = os.path.join(ROOT, 'res', 'askpass.applescript')
    text = 'Making executable {!r}'.format(askpass)
    print_misc(text, os.devnull, verbose)
    with open(askpass, 'w') as file:
        file.write(os.linesep.join(ASKPASS))
    run_script(['chmod', 'u+x', askpass], quiet, verbose)

    PLIST = collections.OrderedDict(
        Label='com.macdaily.askpass',
        ProgramArguments=['/usr/bin/ssh-agent', '-l'],
        EnvironmentVariables=collections.OrderedDict(
            SSH_ASKPASS=askpass,
            DISPLAY=0,
        ),
        Sockets=collections.OrderedDict(
            Listeners=collections.OrderedDict(
                SecureSocketWithKey='SSH_AUTH_SOCK'
            )
        ),
        EnableTransactions=True,
    )
    plist = os.path.expanduser('~/Library/LaunchAgents/com.macdaily.askpass.plist')
    text = 'Adding Launch Agent {!r}'.format(plist)
    print_misc(text, os.devnull, verbose)
    if os.path.exists(plist):
        run_script(['launchctl', 'unload', '-w', plist], quiet, verbose)
    with open(plist, 'wb') as file:
        plistlib.dump(PLIST, file, sort_keys=False)
    run_script(['launchctl', 'load', '-w', plist], quiet, verbose)
    run_script(['ssh-add', '-c'], quiet, verbose)

    return askpass


def launch_confirm(quiet=False, verbose=False):
    text = 'Launching MacDaily Confirmation program'
    print_info(text, os.devnull, quiet)

    path = 'Macintosh HD{}:img:confirm.icns'.format(ROOT.replace(os.path.sep, ":"))
    ASKPASS = ['#!/usr/bin/env osascript',
               '',
               'on run argv',
               '    set args to argv as text',
               '    if args starts with "--help" or args starts with "-h" then',
               '        return "macdaily-confirm [-h|--help] [prompt]"',
               '    end if',
               '    display dialog args with icon file ("{}") default button "Cancel"'.format(path),
               "    return result's button returned",
               'end run',
               '']
    confirm = os.path.join(ROOT, 'res', 'confirm.applescript')
    text = 'Making executable {!r}'.format(confirm)
    print_misc(text, os.devnull, verbose)
    with open(confirm, 'w') as file:
        file.write(os.linesep.join(ASKPASS))
    run_script(['chmod', 'u+x', confirm], quiet, verbose)

    return confirm

==> macdaily-2018.11.7.dev21.tar.gz: macdaily-2018.11.7.dev21/macdaily/cmd/launch.py <==
# -*- coding: utf-8 -*-

import collections
import os
import plistlib

from macdaily.util.const import ROOT, bold, red, reset
from macdaily.util.misc import (make_stderr, print_info, print_misc,
                                print_scpt, print_term)

try:
    import subprocess32 as subprocess
except ImportError:
    import subprocess


def run_script(argv, quiet, verbose):
    args = ' '.join(argv)
    print_scpt(args, os.devnull, verbose)
    try:
        subprocess.check_call(argv, stdout=subprocess.DEVNULL, stderr=make_stderr(quiet))
    except subprocess.CalledProcessError:
        text = "macdaily: {}launch{}: command `{}{!r}{} failed".format(red, reset, bold, args, reset)
        print_term(text, os.devnull, quiet)
        raise


def launch_askpass(quiet=False, verbose=False):
    text = 'Launching MacDaily SSH-AskPass program'
    print_info(text, os.devnull, quiet)

    path = 'Macintosh HD{}:img:askpass.icns'.format(ROOT.replace(os.path.sep, ":"))
    ASKPASS = ['#!/usr/bin/env osascript',
               '',
               '-- script based on https://github.com/theseal/ssh-askpass',
               '',
               'on run argv',
               '    set args to argv as text',
               '    if args starts with "--help" or args starts with "-h" then',
               '        return "macdaily-askpass [-h|--help] [prompt]"',
               '    end if',
               '    display dialog args with icon file ("{}") default button "OK" default answer "" with hidden answer'.format(path),
               "    return result's text returned",
               'end run',
               '']
    askpass = os.path.join(ROOT, 'res', 'askpass.applescript')
    text = 'Making executable {!r}'.format(askpass)
    print_misc(text, os.devnull, verbose)
    with open(askpass, 'w') as file:
        file.write(os.linesep.join(ASKPASS))
    run_script(['chmod', 'u+x', askpass], quiet, verbose)

    PLIST = collections.OrderedDict(
        Label='com.macdaily.askpass',
        ProgramArguments=['/usr/bin/ssh-agent', '-l'],
        EnvironmentVariables=collections.OrderedDict(
            SSH_ASKPASS=askpass,
            DISPLAY=0,
        ),
        Sockets=collections.OrderedDict(
            Listeners=collections.OrderedDict(
                SecureSocketWithKey='SSH_AUTH_SOCK'
            )
        ),
        EnableTransactions=True,
    )
    plist = os.path.expanduser('~/Library/LaunchAgents/com.macdaily.askpass.plist')
    text = 'Adding Launch Agent {!r}'.format(plist)
    print_misc(text, os.devnull, verbose)
    if os.path.exists(plist):
        run_script(['launchctl', 'unload', '-w', plist], quiet, verbose)
    with open(plist, 'wb') as file:
        plistlib.dump(PLIST, file, sort_keys=False)
    run_script(['launchctl', 'load', '-w', plist], quiet, verbose)
    run_script(['ssh-add', '-c'], quiet, verbose)

    return askpass


def launch_confirm(quiet=False, verbose=False):
    text = 'Launching MacDaily Confirmation program'
    print_info(text, os.devnull, quiet)

    path = 'Macintosh HD{}:img:confirm.icns'.format(ROOT.replace(os.path.sep, ":"))
    ASKPASS = ['#!/usr/bin/env osascript',
               '',
               'on run argv',
               '    set args to argv as text',
               '    if args starts with "--help" or args starts with "-h" then',
               '        return "macdaily-confirm [-h|--help] [prompt]"',
               '    end if',
               '    display dialog args with icon file ("{}") default button "Cancel"'.format(path),
               "    return result's button returned",
               'end run',
               '']
    confirm = os.path.join(ROOT, 'res', 'confirm.applescript')
    text = 'Making executable {!r}'.format(confirm)
    print_misc(text, os.devnull, verbose)
    with open(confirm, 'w') as file:
        file.write(os.linesep.join(ASKPASS))
    run_script(['chmod', 'u+x', confirm], quiet, verbose)

    return confirm
